@@ -18,7 +18,7 @@ from pytz import utc
 
 from dataclasses_avroschema import schema_generator, serialization, types, utils
 
-from .exceptions import NameSpaceRequiredException
+from .exceptions import InvalidMap, NameSpaceRequiredException
 
 PY_VER = sys.version_info
 
@@ -160,7 +160,7 @@ class BaseField:
                 * tuple, he OrderedDict will contains the key symbols inside type
                 * dict, he OrderedDict will contains the key values inside type
         """
-        template = OrderedDict([("name", self.name), ("type", self.get_avro_type())] + self.get_metadata())
+        template = OrderedDict(self.get_metadata() + [("name", self.name), ("type", self.get_avro_type())])
 
         default = self.get_default_value()
         if default is not dataclasses.MISSING:
@@ -347,6 +347,12 @@ class DictField(ContainerField):
     values_type: typing.Any = None
     internal_field: typing.Any = None
 
+    def __post_init__(self) -> None:
+        key_type = self.type.__args__[0]
+
+        if key_type is not str:
+            raise InvalidMap(self.name, key_type)
+
     @property
     def avro_type(self) -> typing.Dict[str, typing.Any]:
         self.generate_values_type()
@@ -691,15 +697,13 @@ class RecordField(BaseField):
         alias = self.parent.metadata.get_alias_nested_items(self.name) or metadata.get_alias_nested_items(self.name)  # type: ignore  # noqa E501
 
         # The priority for the schema name
-        # 1. Check if the schema_name is present in the Meta class of own model
-        # 2. Check if exists an alias_nested_items in parent class or Meta class of own model
+        # 1. Check if exists an alias_nested_items in parent class or Meta class of own model
+        # 2. Check if the schema_name is present in the Meta class of own model
         # 3. Use the default class Name (self.type.__name__)
-        name = metadata.schema_name or alias or self.type.__name__
+        name = alias or metadata.schema_name or self.type.__name__
 
-        if not self.exist_type():
+        if not self.exist_type() or alias is not None:
             user_defined_type = utils.UserDefinedType(name=name, type=self.type)
-
-            # add user_defined_type to the parent
             self.parent.user_defined_types += (user_defined_type,)
 
             record_type = self.type.avro_schema_to_python(root=self.parent)
